@@ -26,7 +26,8 @@ from .account import get_historical_portfolio,      \
                      post_symbols_to_watchlist,     \
                      delete_symbols_from_watchlist, \
                      build_holdings,                \
-                     build_user_profile
+                     build_user_profile,            \
+                     load_phoenix_account
 
 from .authentication import login, \
                             logout
@@ -48,9 +49,16 @@ from .helper import request_get,      \
                     request_document, \
                     update_session
 
-from .markets import get_currency_pairs,        \
-                     get_markets,               \
-                     get_top_movers
+from .markets import get_currency_pairs,                    \
+                     get_markets,                           \
+                     get_market_today_hours,                \
+                     get_market_next_open_hours,            \
+                     get_market_next_open_hours_after_date, \
+                     get_market_hours,                      \
+                     get_all_stocks_from_market_tag,        \
+                     get_top_movers,                        \
+                     get_top_movers_sp500,                  \
+                     get_top_100
 
 from .options import get_aggregate_positions,                           \
                      get_market_options,                                \
@@ -61,54 +69,54 @@ from .options import get_aggregate_positions,                           \
                      find_options_by_expiration,                        \
                      find_options_by_strike,                            \
                      find_options_by_expiration_and_strike,             \
-                     find_options_by_specific_profitability,        \
+                     find_options_by_specific_profitability,            \
                      get_option_market_data_by_id,                      \
                      get_option_market_data,                            \
                      get_option_instrument_data_by_id,                  \
                      get_option_instrument_data,                        \
                      get_option_historicals
 
-from .orders import get_all_stock_orders,           \
-                    get_all_option_orders,          \
-                    get_all_crypto_orders,          \
-                    get_all_open_stock_orders,      \
-                    get_all_open_option_orders,     \
-                    get_all_open_crypto_orders,     \
-                    get_stock_order_info,           \
-                    get_option_order_info,          \
-                    get_crypto_order_info,          \
-                    find_stock_orders,              \
-                    cancel_all_stock_orders,        \
-                    cancel_all_option_orders,       \
-                    cancel_all_crypto_orders,       \
-                    cancel_stock_order,             \
-                    cancel_option_order,            \
-                    cancel_crypto_order,            \
-                    order,                          \
-                    order_buy_market,               \
-                    order_buy_fractional_by_quantity,\
-                    order_buy_fractional_by_price,  \
-                    order_buy_limit,                \
-                    order_buy_stop_loss,            \
-                    order_buy_stop_limit,           \
-                    order_sell_market,              \
-                    order_sell_fractional_by_quantity,\
-                    order_sell_fractional_by_price, \
-                    order_sell_limit,               \
-                    order_sell_stop_loss,           \
-                    order_sell_stop_limit,          \
-                    order_buy_option_stop_limit,    \
-                    order_sell_option_stop_limit,   \
-                    order_buy_option_limit,         \
-                    order_sell_option_limit,        \
-                    order_option_spread,            \
-                    order_option_credit_spread,     \
-                    order_option_debit_spread,      \
-                    order_buy_crypto_by_price,      \
-                    order_buy_crypto_by_quantity,   \
-                    order_buy_crypto_limit,         \
-                    order_sell_crypto_by_price,     \
-                    order_sell_crypto_by_quantity,  \
+from .orders import get_all_stock_orders,               \
+                    get_all_option_orders,              \
+                    get_all_crypto_orders,              \
+                    get_all_open_stock_orders,          \
+                    get_all_open_option_orders,         \
+                    get_all_open_crypto_orders,         \
+                    get_stock_order_info,               \
+                    get_option_order_info,              \
+                    get_crypto_order_info,              \
+                    find_stock_orders,                  \
+                    cancel_all_stock_orders,            \
+                    cancel_all_option_orders,           \
+                    cancel_all_crypto_orders,           \
+                    cancel_stock_order,                 \
+                    cancel_option_order,                \
+                    cancel_crypto_order,                \
+                    order,                              \
+                    order_buy_market,                   \
+                    order_buy_fractional_by_quantity,   \
+                    order_buy_fractional_by_price,      \
+                    order_buy_limit,                    \
+                    order_buy_stop_loss,                \
+                    order_buy_stop_limit,               \
+                    order_sell_market,                  \
+                    order_sell_fractional_by_quantity,  \
+                    order_sell_fractional_by_price,     \
+                    order_sell_limit,                   \
+                    order_sell_stop_loss,               \
+                    order_sell_stop_limit,              \
+                    order_buy_option_stop_limit,        \
+                    order_sell_option_stop_limit,       \
+                    order_buy_option_limit,             \
+                    order_sell_option_limit,            \
+                    order_option_spread,                \
+                    order_option_credit_spread,         \
+                    order_option_debit_spread,          \
+                    order_buy_crypto_by_price,          \
+                    order_buy_crypto_by_quantity,       \
+                    order_buy_crypto_limit,             \
+                    order_sell_crypto_by_price,         \
+                    order_sell_crypto_by_quantity,      \
                     order_sell_crypto_limit
 
 from .profiles import load_account_profile,     \
@@ -127,7 +135,6 @@ from .stocks import get_quotes,                 \
                     get_name_by_url,            \
                     get_symbol_by_url,          \
                     get_ratings,                \
-                    get_popularity,             \
                     get_events,                 \
                     get_earnings,               \
                     get_news,                   \
