@@ -10,7 +10,7 @@ SESSION.headers = {
     "Accept-Encoding": "gzip,deflate,br",
     "Accept-Language": "en-US,en;q=1",
     "Content-Type": "application/x-www-form-urlencoded; charset=utf-8",
-    "X-Robinhood-API-Version": "1.0.0",
+    "X-Robinhood-API-Version": "1.315.0",
     "Connection": "keep-alive",
-    "User-Agent": "Robinhood/823 (iphone; iOS 7.1.2, Scale/2.00)"
+    "User-Agent": "*"
 }
