@@ -194,11 +194,13 @@ def get_instrument_by_url(url, info=None):
     return(helper.filter(data, info))
 
 
-def get_latest_price(inputSymbols, includeExtendedHours=True):
+def get_latest_price(inputSymbols, priceType=None, includeExtendedHours=True):
     """Takes any number of stock tickers and returns the latest price of each one as a string.
 
     :param inputSymbols: May be a single stock ticker or a list of stock tickers.
     :type inputSymbols: str or list
+    :param priceType: Can either be 'ask_price' or 'bid_price'. If this parameter is set, then includeExtendedHours is ignored.
+    :type priceType: str
     :param includeExtendedHours: Leave as True if you want to get extendedhours price if available. \
     False if you only want regular hours price, even after hours.
     :type includeExtendedHours: bool
@@ -211,10 +213,17 @@ def get_latest_price(inputSymbols, includeExtendedHours=True):
     prices = []
     for item in quote:
         if item:
-            if item['last_extended_hours_trade_price'] is None or not includeExtendedHours:
-                prices.append(item['last_trade_price'])
+            if priceType == 'ask_price':
+                prices.append(item['ask_price'])
+            elif priceType == 'bid_price':
+                prices.append(item['bid_price'])
             else:
-                prices.append(item['last_extended_hours_trade_price'])
+                if priceType:
+                    print('WARNING: priceType should be "ask_price" or "bid_price". You entered "{0}"'.format(priceType))
+                if item['last_extended_hours_trade_price'] is None or not includeExtendedHours:
+                    prices.append(item['last_trade_price'])
+                else:
+                    prices.append(item['last_extended_hours_trade_price'])
         else:
             prices.append(None)
     return(prices)
@@ -316,32 +325,7 @@ def get_ratings(symbol, info=None):
             item['text'] = oldText.encode('UTF-8')
 
     return(helper.filter(data, info))
-
-@helper.convert_none_to_string
-def get_popularity(symbol, info=None):
-    """Returns the number of open positions.
-
-    :param symbol: The stock ticker.
-    :type symbol: str
-    :param info: Will filter the results to be a string value.
-    :type info: Optional[str]
-    :returns: [dict] If the info parameter is provided, then the function will extract the value of the key \
-    that matches the info parameter. Otherwise, the whole dictionary is returned.
-    :Dictionary Keys: * instrument
-                      * num_open_positions
-
-    """
-    try:
-        symbol = symbol.upper().strip()
-    except AttributeError as message:
-        print(message)
-        return None
-
-    url = urls.popularity(symbol)
-    data = helper.request_get(url)
-
-    return(helper.filter(data, info))
-
+    
 
 def get_events(symbol, info=None):
     """Returns the events related to a stock that the user owns. For example, if you owned options for USO and that stock \
@@ -386,7 +370,7 @@ def get_events(symbol, info=None):
 
 
 def get_earnings(symbol, info=None):
-    """Returns the earnings for the differenct financial quarters.
+    """Returns the earnings for the different financial quarters.
 
     :param symbol: The stock ticker.
     :type symbol: str
@@ -539,7 +523,7 @@ def get_stock_historicals(inputSymbols, interval='hour', span='week', bounds='re
     :type interval: Optional[str]
     :param span: Sets the range of the data to be either 'day', 'week', 'month', '3month', 'year', or '5year'. Default is 'week'.
     :type span: Optional[str]
-    :param bounds: Represents if graph will include extended trading hours or just regular trading hours. Values are 'extended' or 'regular'. Default is 'regular'
+    :param bounds: Represents if graph will include extended trading hours or just regular trading hours. Values are 'extended', 'trading', or 'regular'. Default is 'regular'
     :type bounds: Optional[str]
     :param info: Will filter the results to have a list of the values that correspond to key that matches info.
     :type info: Optional[str]
